================
Shift Management
================

.. 
   !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
   !! This file is generated by oca-gen-addon-readme !!
   !! changes will be overwritten.                   !!
   !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
   !! source digest: sha256:0d5c51a0ceadd42e75fab41e6530a6e270957b77b33eae65266931089f1d95de
   !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

.. |badge1| image:: https://img.shields.io/badge/maturity-Beta-yellow.png
    :target: https://odoo-community.org/page/development-status
    :alt: Beta
.. |badge2| image:: https://img.shields.io/badge/licence-AGPL--3-blue.png
    :target: http://www.gnu.org/licenses/agpl-3.0-standalone.html
    :alt: License: AGPL-3
.. |badge3| image:: https://img.shields.io/badge/github-beescoop%2FObeesdoo-lightgray.png?logo=github
    :target: https://github.com/beescoop/Obeesdoo/tree/16.0/shift
    :alt: beescoop/Obeesdoo

|badge1| |badge2| |badge3|

Generate and manage shifts for cooperators.

**Table of contents**

.. contents::
   :local:

Configuration
=============

- Translate cooperative status selection field, the terms to translate are:

  - shift_status_up_to_date,
  - shift_status_holidays,
  - shift_status_warning,
  - shift_status_extension,
  - shift_status_suspended,
  - shift_status_exempted,
  - shift_status_unsubscribed,
  - shift_status_resigning.

- Configure "Send weekly shift summary" cron:

  - Its interval number (default = 7) should be consistent with notice (default = 1) and period (default = 7).

Changelog
=========

16.0.1.1.1 (2024-11-01)
~~~~~~~~~~~~~~~~~~~~~~~

**Bugfixes**

- Correctly recompute ``can_shop`` on partner when the value changes in the
  ``cooperative_status``. (`#536 <https://github.com/beescoop/Obeesdoo/issues/536>`_)


12.0.2.1.0 (2022-06-21)
~~~~~~~~~~~~~~~~~~~~~~~

**Features**

- When subscribing a worker to a shift template in the backend :
  if no super cooperator is set on template and worker is super cooperator
  automatically set them as super cooperator.
  The worker must have a user linked to it. (`#303 <https://github.com/beescoop/obeesdoo/issues/303>`_)


12.0.1.1.4 (2022-05-26)
**Bugfixes**

- When changing a regular worker to an irregular worker via the wizard, no longer
  give an error when their (former) shift is full. (`#390 <https://github.com/beescoop/obeesdoo/issues/390>`_)


12.0.1.1.1 (2022-05-26)
**Bugfixes**

- No longer raise an error when unsubscribing a replacement worker using the
  wizard. (`#389 <https://github.com/beescoop/obeesdoo/issues/389>`_)

Bug Tracker
===========

Bugs are tracked on `GitHub Issues <https://github.com/beescoop/Obeesdoo/issues>`_.
In case of trouble, please check there if your issue has already been reported.
If you spotted it first, help us to smash it by providing a detailed and welcomed
`feedback <https://github.com/beescoop/Obeesdoo/issues/new?body=module:%20shift%0Aversion:%2016.0%0A%0A**Steps%20to%20reproduce**%0A-%20...%0A%0A**Current%20behavior**%0A%0A**Expected%20behavior**>`_.

Do not contact contributors directly about support or help with technical issues.

Credits
=======

Authors
~~~~~~~

* Thibault Francois
* Elouan Le Bars
* Coop IT Easy SC
* 

Contributors
~~~~~~~~~~~~

* BEES coop - Cellule IT
* Coop IT Easy SC

Maintainers
~~~~~~~~~~~

This module is part of the `beescoop/Obeesdoo <https://github.com/beescoop/Obeesdoo/tree/16.0/shift>`_ project on GitHub.

You are welcome to contribute.
